@@ -42,6 +42,8 @@
 #include "nm-connection-list.h"
 #include "nm-connection-editor.h"
 
+gboolean nm_ce_keep_above;
+
 static GMainLoop *loop = NULL;
 
 #define ARG_TYPE      "type"
@@ -357,6 +359,9 @@ main (int argc, char *argv[])
 		{ ARG_CREATE, 'c', 0, G_OPTION_ARG_NONE,   &create, "Create a new connection", NULL },
 		{ ARG_SHOW,   's', 0, G_OPTION_ARG_NONE,   &show,   "Show a given connection type page", NULL },
 		{ "edit",     'e', 0, G_OPTION_ARG_STRING, &uuid,   "Edit an existing connection with a given UUID", "UUID" },
+
+		/* This is not passed over D-Bus. */
+		{ "keep-above", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &nm_ce_keep_above, NULL, NULL },
 		{ NULL }
 	};
 
