@@ -83,6 +83,8 @@
 #include "vpn-helpers.h"
 #include "eap-method.h"
 
+extern gboolean nm_ce_keep_above;
+
 G_DEFINE_TYPE (NMConnectionEditor, nm_connection_editor, G_TYPE_OBJECT)
 
 enum {
@@ -293,6 +295,9 @@ nm_connection_editor_init (NMConnectionEditor *editor)
 	}
 
 	editor->window = GTK_WIDGET (gtk_builder_get_object (editor->builder, "nm-connection-editor"));
+	if (nm_ce_keep_above)
+		gtk_window_set_keep_above (GTK_WINDOW (editor->window), TRUE);
+
 	editor->cancel_button = GTK_WIDGET (gtk_builder_get_object (editor->builder, "cancel_button"));
 	editor->export_button = GTK_WIDGET (gtk_builder_get_object (editor->builder, "export_button"));
 }
@@ -977,6 +982,7 @@ static void
 ok_button_clicked_cb (GtkWidget *widget, gpointer user_data)
 {
 	NMConnectionEditor *self = NM_CONNECTION_EDITOR (user_data);
+	GSList *iter;
 
 	/* If the dialog is busy waiting for authorization or something,
 	 * don't destroy it until authorization returns.
@@ -987,6 +993,10 @@ ok_button_clicked_cb (GtkWidget *widget, gpointer user_data)
 	/* Validate one last time to ensure all pages update the connection */
 	connection_editor_validate (self);
 
+	/* Perform page specific actions before the connection is saved */
+	for (iter = self->pages; iter; iter = g_slist_next (iter))
+		ce_page_last_update (CE_PAGE (iter->data), self->connection, NULL);
+
 	ok_button_clicked_save_connection (self);
 }
 
